"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystemWatcher = void 0;
const ide_core_common_1 = require("@opensumi/ide-core-common");
function filterChange(fileChangeList, watchUri) {
    return fileChangeList.filter((fileChange) => {
        if (fileChange.uri.startsWith(watchUri)) {
            return true;
        }
        return false;
    });
}
class FileSystemWatcher {
    constructor(options) {
        this.toDispose = new ide_core_common_1.DisposableCollection();
        this.changeEmitter = new ide_core_common_1.Emitter();
        this.toDispose.push(this.changeEmitter);
        this.fileServiceClient = options.fileServiceClient;
        this.watchId = options.watchId;
        this.uri = options.uri;
        this.fileServiceClient.onFilesChanged((fileChangeList) => {
            const result = filterChange(fileChangeList, this.uri.toString());
            if (result && result.length > 0) {
                this.changeEmitter.fire(result);
            }
        });
    }
    get onFilesChanged() {
        return this.changeEmitter.event;
    }
    dispose() {
        return Promise.all([
            this.toDispose.dispose(),
            this.fileServiceClient.unwatchFileChanges(this.watchId),
        ]);
    }
    isDisposed() {
        return this.toDispose.disposed;
    }
}
exports.FileSystemWatcher = FileSystemWatcher;
//# sourceMappingURL=watcher.js.map