"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFileType = void 0;
const tslib_1 = require("tslib");
const file_type_1 = tslib_1.__importDefault(require("file-type"));
const fse = tslib_1.__importStar(require("fs-extra"));
const ide_core_common_1 = require("@opensumi/ide-core-common");
const common_1 = require("../../common");
async function getFileType(uri) {
    try {
        // 兼容性处理，本质 disk-file 不支持非 file 协议的文件头嗅探
        if (!uri.startsWith('file:/')) {
            return (0, common_1.getFileTypeByExt)();
        }
        const stat = await fse.stat(ide_core_common_1.FileUri.fsPath(uri));
        if (stat.isDirectory()) {
            return 'directory';
        }
        else {
            let ext;
            if (stat.size) {
                const type = await file_type_1.default.stream(fse.createReadStream(ide_core_common_1.FileUri.fsPath(uri)));
                // 可以拿到 type.fileType 说明为二进制文件
                if (type.fileType) {
                    if (type.fileType.mime) {
                        if (type.fileType.mime.startsWith('image/')) {
                            return "image" /* EditorFileType.Image */;
                        }
                        if (type.fileType.mime.startsWith('video/')) {
                            return "video" /* EditorFileType.Video */;
                        }
                    }
                    ext = type.fileType.ext;
                }
            }
            return (0, common_1.getFileTypeByExt)(ext);
        }
    }
    catch (error) {
        if ((0, common_1.isErrnoException)(error)) {
            if (error.code === 'ENOENT' || error.code === 'EACCES' || error.code === 'EBUSY' || error.code === 'EPERM') {
                return undefined;
            }
        }
    }
}
exports.getFileType = getFileType;
//# sourceMappingURL=file-type.js.map